#
# spec file for package python-decorator
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-decorator
Version:        4.2.1
Release:        lp150.1.3
Url:            http://pypi.python.org/pypi/decorator
Summary:        Better living through Python with decorators
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/d/decorator/decorator-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%python_subpackages

%description
As of now, writing custom decorators correctly requires some experience and it
is not as easy as it could be. For instance, typical implementations of
decorators involve nested functions, and we all know that flat is better than
nested. Moreover, typical implementations of decorators do not preserve the
signature of decorated functions, thus confusing both documentation tools and
developers.

The aim of the decorator module it to simplify the usage of decorators for the
average programmer, and to popularize decorators usage giving examples of
useful decorators, such as memoize, tracing, redirecting_stdout, locked, etc.

%prep
%setup -q -n decorator-%{version}
sed -i 's/\r//' docs/README.rst # Fix EOL encoding

%build
%python_build

%install
%python_install

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES.md LICENSE.txt docs/README.rst
%{python_sitelib}/decorator.py*
%pycache_only %{python_sitelib}/__pycache__/decorator.*.py*
%{python_sitelib}/decorator-%{version}-py*.egg-info

%changelog
* Wed Jan 17 2018 arun@gmx.de
- specfile:
  - updated copyright year
- updated to version 4.2.1:
  * Fixed a regression breaking IPython reported by
    https://github.com/spapini .
- changes from version 4.2.0 :
  * Added a facility to define families of decorators (aka decorators
    with arguments) as requested by several users. Accepted a pylint
    patch by David Allouche.
* Wed Aug  9 2017 tbechtold@suse.com
- update to 4.1.2:
  * Made it possible to define decorators converting coroutines into regular
    functions.
  * Changed the documentation build system to sphinx and uploaded the docs
    on readthedocs.org.
  * Support for Python 3.5 coroutines defined with `async def`, thanks to
    Victor-Nicolae Savu who raised the issue of `iscoroutinefunction` not
    giving the right answer for coroutines decorated with the decorator module.
* Wed Apr  5 2017 jmatejek@suse.com
- fix source url
* Sat Apr  1 2017 toddrme2178@gmail.com
- Update to 4.0.11
  * Small improvements to the documentation and tested with Python 3.6
- Update to 4.0.10
  * Improved the documentation thanks to Tony Goodchild (zearin) who also
    provided a much better CSS than the one I was using.
- Update to 4.0.9
  * Same as 4.0.7 and 4.0.8, re-uploaded due to issues on PyPI.
- Update to 4.0.7
  * Switched to a new changelog format (the one in http://keepachangelog.com/)
    since it was contributed by Alexander Artemenko. Re-added a newline to support
    old version of Python, as requested by [azjps](https://github.com/azjps).
- Update to 4.0.6
  * Removed a file x.py accidentally entered in the tarball.
- Update to 4.0.5
  * Documented a quirk signaled by David Goldstein when writing decorators
    for functions with keyword arguments. Avoided copying the globals,
    as signaled by Benjamin Peterson.
- Update to 4.0.4
  * Included a patch from Zev Benjamin: now decorated functions play well
    with cProfile.
- Update to 4.0.3
  * Added a warning about the memoize example, as requested by Robert
    Buchholz.
- Update to 4.0.2
  * docs/README.rst was not included in MANIFEST.in by accident,
    thus breaking the source installation.
- Update to 4.0.1
  * Added docs directory and upload_docs command. Fixed bug with
    `__qualname__`, reported by Lucian Petrut.
- Update to 4.0.0
  * Removed the need for 2to3 by dropping the support for Python 2.5.
  * Added a MANIFEST.in file and produced a proper wheel. Improved
    the integration with setuptools so that `python setup.py test` works.
  * Reworked the documentation and introduced `decorator.decorated`.
  * Removed any dependence from `inspect.getargspec`, which is deprecated
    in Python 3.5, as signaled by Ralf Gommers.
  * Fixed `contextmanager` to work with Python 3.5.
  * Copied the `__qualname__` attribute, as requested by Frazer McLean.
  * Added a `dispatch_on` facility to implement generic functions.
- Implement single-spec version.
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 3.4.2:
  * Same as 3.4.1, re-uploaded to PyPI
- additional changes from version 3.4.1:
  * Ported the repository from GoogleCode to GitHub and added
    Travis CI support
  * Tests are executed with the new command `python test.py -v`
  * setuptools is now mandatory in Python 3
  * The suggested installation tool is `pip`, not `easy_install`
  * Supported IronPython and other Python implementations without
    sys._getframe, as requested by Doug Blank
- remove python-nose from BuildRequires, unneeded
- replace README.txt with README.rst: changed upstream
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jun 25 2013 dmueller@suse.com
- update to 3.4.0:
  * Added the ability to use classes and generic callables as callers and
  implemented a signature-preserving contexmanager decorator. Fixed a bug
  with the signature f(**kw) in Python 3 and fixed a couple of doctests
  broken by Python 3.3, both issues pointed out by Dominic Sacré (18/10/2012)
* Wed May 23 2012 highwaystar.ru@gmail.com
- update to version 3.3.3
- minor spec improvement
- python3 package added
* Tue Nov 29 2011 cfarrell@suse.com
- license update: BSD-2-Clause
  SPDX format
* Thu Nov 24 2011 idoenmez@suse.de
- Update to upstream tarball, no code changes
* Mon Sep 26 2011 saschpe@suse.de
- Add python-distribute (setuptools) BuildRequires, seemed to got lost
* Thu Sep  1 2011 saschpe@suse.de
- Update to version 3.3.2
- Added proper changes file
* Thu Jan  7 2010 hpj@urpla.net
- Update to 3.3.0
* Mon Aug 10 2009 cfarrell1980@gmail.com
- Update to 3.0.1
* Tue Dec  2 2008 jfunk@funktronics.ca
- Initial release
